import { Header } from '@/views/Service'
import Link from 'next/link'
import { IconChevronLeft } from '@tabler/icons'

import { ServiceContent } from '../../types/ServiceContent'
import useContent from 'shared/use-content'
import useImgPath from 'shared/use-img-path'

import { translateStatusLableValue } from '@/lib/utils/labelHelper'
const initializedUsedContent = useContent('standards')
const { getImgPath } = useImgPath()

export default function ({ contentString }) {
    const content: ServiceContent = JSON.parse(contentString)
    return (
        <div className={'mx-auto max-w-screen-xl it-standard'}>
            <nav className="relative max-w-7xl flex">
                <div className="flex items-center flex-1">
                    <div className="flex items-center justify-between w-full md:w-auto">
                        {/* Backlink zur Übersicht oben links */}
                        <div className="hidden lg:flex">
                            <Link href="/standards" passHref legacyBehavior>
                                <a className={'text-lg font-bold text-yellow-400 hover:text-gray-900'}>
                                    Zurück zur Übersicht!
                                </a>
                            </Link>
                        </div>
                        {/* alternativer Backlink zur Übersicht oben links mit Pfeilsymbol auf schmalen Bildschirm */}
                        <div className="flex lg:hidden">
                            <Link href="/standards" passHref legacyBehavior>
                                <a>
                                    <IconChevronLeft
                                        className="m-6 text-yellow-400 hover:text-gray-900"
                                        aria-hidden="true"
                                    />
                                </a>
                            </Link>
                        </div>
                    </div>
                </div>
            </nav>
            <Header
                contact={{
                    name: content.contactInformation.name,
                    mail: content.contactInformation.mail,
                }}
                img={{
                    src: getImgPath(content.logo.path),
                    alt: content.logo.title,
                }}
                title={content?.name}
                description={content?.text}
                developer={{
                    name: content?.developer.name,
                    link: content?.developer.url,
                }}
                statusLabel={translateStatusLableValue(content.status)}
                documentationURL={content.docsUrl}
                sourceURL={content.sourceCodeUrl}
                resources={content.childResources}
            />
        </div>
    )
}

export async function getStaticProps({ params }) {
    const content = initializedUsedContent.contentByServiceName(params.serviceName)
    console.log(content)
    return {
        props: {
            contentString: JSON.stringify(content),
        },
    }
}

export async function getStaticPaths() {
    const { contents } = useContent('standards')
    const servicePaths = contents.map((content) => {
        return { params: { serviceName: content.slug } }
    })

    return {
        paths: servicePaths,
        fallback: false,
    }
}
